# Generated by Django 3.2.5 on 2023-02-09 11:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bank_sync', '0014_auto_20230125_1119'),
    ]

    operations = [
        migrations.AddField(
            model_name='callbacks',
            name='business_id',
            field=models.UUIDField(default=None, editable=False, null=True),
        ),
        migrations.AddField(
            model_name='callbacks',
            name='tenant_id',
            field=models.UUIDField(default=None, editable=False, null=True),
        ),
        migrations.AddField(
            model_name='ipn',
            name='business_id',
            field=models.UUIDField(default=None, editable=False, null=True),
        ),
        migrations.AddField(
            model_name='ipn',
            name='tenant_id',
            field=models.UUIDField(default=None, editable=False, null=True),
        ),
    ]
