# Generated by Django 3.2.5 on 2022-11-09 08:32

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('bank_sync', '0006_requestlogs_log_time'),
    ]

    operations = [
        migrations.CreateModel(
            name='ResponseLogs',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('headers', models.JSONField(default=dict)),
                ('content', models.JSONField(default=dict)),
                ('log_time', models.DateTimeField(default=django.utils.timezone.now)),
            ],
        ),
    ]
