# Generated by Django 3.2.5 on 2022-11-08 13:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bank_sync', '0003_requestlogs'),
    ]

    operations = [
        migrations.AddField(
            model_name='requestlogs',
            name='error',
            field=models.TextField(default=None),
        ),
    ]
